@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import datetime
+import logging
 import pprint
 import time
 import urllib
@@ -17,22 +18,26 @@ from paypal.pro.models import PayPalNVP, L
 from paypal.pro.exceptions import PayPalFailure
 
 TEST = settings.PAYPAL_TEST
-USER = settings.PAYPAL_WPP_USER 
+USER = settings.PAYPAL_WPP_USER
 PASSWORD = settings.PAYPAL_WPP_PASSWORD
 SIGNATURE = settings.PAYPAL_WPP_SIGNATURE
 VERSION = 54.0
-BASE_PARAMS = dict(USER=USER , PWD=PASSWORD, SIGNATURE=SIGNATURE, VERSION=VERSION)
+BASE_PARAMS = dict(USER=USER, PWD=PASSWORD, SIGNATURE=SIGNATURE, VERSION=VERSION)
 ENDPOINT = "https://api-3t.paypal.com/nvp"
 SANDBOX_ENDPOINT = "https://api-3t.sandbox.paypal.com/nvp"
 NVP_FIELDS = fields_for_model(PayPalNVP).keys()
 
 
+log = logging.getLogger(__file__)
+
+
 def paypal_time(time_obj=None):
     """Returns a time suitable for PayPal time fields."""
     if time_obj is None:
         time_obj = time.gmtime()
     return time.strftime(PayPalNVP.TIMESTAMP_FORMAT, time_obj)
-    
+
+
 def paypaltime2datetime(s):
     """Convert a PayPal time string to a DateTime."""
     return datetime.datetime(*(time.strptime(s, PayPalNVP.TIMESTAMP_FORMAT)[:6]))
@@ -40,7 +45,7 @@ def paypaltime2datetime(s):
 
 class PayPalError(TypeError):
     """Error thrown when something be wrong."""
-    
+
 
 class PayPalWPP(object):
     """
@@ -52,6 +57,7 @@ class PayPalWPP(object):
     Name-Value Pair API Developer Guide and Reference:
     https://cms.paypal.com/cms_content/US/en_US/files/developer/PP_NVPAPI_DeveloperGuide.pdf
     """
+
     def __init__(self, request, params=BASE_PARAMS):
         """Required - USER / PWD / SIGNATURE / VERSION"""
         self.request = request
@@ -65,7 +71,8 @@ class PayPalWPP(object):
     def doDirectPayment(self, params):
         """Call PayPal DoDirectPayment method."""
         defaults = {"method": "DoDirectPayment", "paymentaction": "Sale"}
-        required = L("creditcardtype acct expdate cvv2 ipaddress firstname lastname street city state countrycode zip amt")
+        required = L(
+            "creditcardtype acct expdate cvv2 ipaddress firstname lastname street city state countrycode zip amt")
         nvp_obj = self._fetch(params, required, defaults)
         if nvp_obj.flag:
             raise PayPalFailure(nvp_obj.flag_info)
@@ -106,7 +113,7 @@ class PayPalWPP(object):
             raise PayPalFailure(nvp_obj.flag_info)
         payment_was_successful.send(params)
         return nvp_obj
-        
+
     def createRecurringPaymentsProfile(self, params, direct=False):
         """
         Set direct to True to indicate that this is being called as a directPayment.
@@ -122,10 +129,11 @@ class PayPalWPP(object):
             required + L("token payerid")
 
         nvp_obj = self._fetch(params, required, defaults)
-        
+
         # Flag if profile_type != ActiveProfile
         if nvp_obj.flag:
             raise PayPalFailure(nvp_obj.flag_info)
+        payment_profile_created.send(params)
         return nvp_obj
 
     def getExpressCheckoutDetails(self, params):
@@ -162,10 +170,10 @@ class PayPalWPP(object):
         if nvp_obj.flag:
             raise PayPalFailure(nvp_obj.flag_info)
         return nvp_obj
-    
+
     def billOutstandingAmount(self, params):
         raise NotImplementedError
-        
+
     def manangeRecurringPaymentsProfileStatus(self, params, fail_silently=False):
         """
         Requires `profileid` and `action` params.
@@ -177,7 +185,8 @@ class PayPalWPP(object):
         nvp_obj = self._fetch(params, required, defaults)
 
         # TODO: This fail silently check should be using the error code, but its not easy to access
-        if not nvp_obj.flag or (fail_silently and nvp_obj.flag_info == 'Invalid profile status for cancel action; profile should be active or suspended'):
+        if not nvp_obj.flag or (
+            fail_silently and nvp_obj.flag_info == 'Invalid profile status for cancel action; profile should be active or suspended'):
             if params['action'] == 'Cancel':
                 recurring_cancel.send(sender=nvp_obj)
             elif params['action'] == 'Suspend':
@@ -187,7 +196,7 @@ class PayPalWPP(object):
         else:
             raise PayPalFailure(nvp_obj.flag_info)
         return nvp_obj
-        
+
     def refundTransaction(self, params):
         raise NotImplementedError
 
@@ -207,7 +216,7 @@ class PayPalWPP(object):
         for k in params.keys():
             if k in REMOVE:
                 del params[k]
-                
+
         return params
 
     def _fetch(self, params, required, defaults):
@@ -217,12 +226,10 @@ class PayPalWPP(object):
         pp_string = self.signature + urlencode(pp_params)
         response = self._request(pp_string)
         response_params = self._parse_response(response)
-        
+
         if getattr(settings, 'PAYPAL_DEBUG', settings.DEBUG):
-            print 'PayPal Request:'
-            pprint.pprint(defaults)
-            print '\nPayPal Response:'
-            pprint.pprint(response_params)
+            log.debug('PayPal Request:\n%s\n', pprint.pformat(defaults))
+            log.debug('PayPal Response:\n%s\n', pprint.pformat(response_params))
 
         # Gather all NVP parameters to pass to a new instance.
         nvp_params = {}
@@ -238,7 +245,7 @@ class PayPalWPP(object):
         nvp_obj.init(self.request, params, response_params)
         nvp_obj.save()
         return nvp_obj
-        
+
     def _request(self, data):
         """Moved out to make testing easier."""
         return urllib2.urlopen(self.endpoint, data).read()
@@ -250,7 +257,7 @@ class PayPalWPP(object):
         """
         for r in required:
             if r not in params:
-                raise PayPalError("Missing required param: %s" % r)    
+                raise PayPalError("Missing required param: %s" % r)
 
         # Upper case all the parameters for PayPal.
         return (dict((k.upper(), v) for k, v in params.iteritems()))
@@ -261,4 +268,4 @@ class PayPalWPP(object):
         for kv in response.split('&'):
             key, value = kv.split("=")
             response_tokens[key.lower()] = urllib.unquote(value)
-        return response_tokens
\ No newline at end of file
+        return response_tokens
