@@ -5,11 +5,13 @@ from django.db import models
 from django.utils.http import urlencode
 from django.forms.models import model_to_dict
 from django.contrib.auth.models import User
+
 try:
     from idmapper.models import SharedMemoryModel as Model
 except ImportError:
     Model = models.Model
 
+
 class PayPalNVP(Model):
     """Record of a NVP interaction with PayPal."""
     TIMESTAMP_FORMAT = "%Y-%m-%dT%H:%M:%SZ"  # 2009-02-03T17:47:41Z
@@ -20,7 +22,7 @@ class PayPalNVP(Model):
 
     # Response fields
     method = models.CharField(max_length=64, blank=True)
-    ack = models.CharField(max_length=32, blank=True)    
+    ack = models.CharField(max_length=32, blank=True)
     profilestatus = models.CharField(max_length=32, blank=True)
     timestamp = models.DateTimeField(blank=True, null=True)
     profileid = models.CharField(max_length=32, blank=True)  # I-E596DFUSD882
@@ -28,43 +30,43 @@ class PayPalNVP(Model):
     correlationid = models.CharField(max_length=32, blank=True) # 25b380cda7a21
     token = models.CharField(max_length=64, blank=True)
     payerid = models.CharField(max_length=64, blank=True)
-    
+
     # Transaction Fields
     firstname = models.CharField("First Name", max_length=255, blank=True)
     lastname = models.CharField("Last Name", max_length=255, blank=True)
     street = models.CharField("Street Address", max_length=255, blank=True)
     city = models.CharField("City", max_length=255, blank=True)
     state = models.CharField("State", max_length=255, blank=True)
-    countrycode = models.CharField("Country", max_length=2,blank=True)
+    countrycode = models.CharField("Country", max_length=2, blank=True)
     zip = models.CharField("Postal / Zip Code", max_length=32, blank=True)
-    
+
     # Custom fields
     invnum = models.CharField(max_length=255, blank=True)
-    custom = models.CharField(max_length=255, blank=True) 
-    
+    custom = models.CharField(max_length=255, blank=True)
+
     # Admin fields
     user = models.ForeignKey(User, blank=True, null=True)
     flag = models.BooleanField(default=False, blank=True)
     flag_code = models.CharField(max_length=32, blank=True)
-    flag_info = models.TextField(blank=True)    
+    flag_info = models.TextField(blank=True)
     ipaddress = models.IPAddressField(blank=True)
     query = models.TextField(blank=True)
     response = models.TextField(blank=True)
     created_at = models.DateTimeField(auto_now_add=True)
     updated_at = models.DateTimeField(auto_now=True)
-        
+
     class Meta:
         db_table = "paypal_nvp"
         verbose_name = "PayPal NVP"
-    
+
     def init(self, request, paypal_request, paypal_response):
         """Initialize a PayPalNVP instance from a HttpRequest."""
-        self.ipaddress = request.META.get('REMOTE_ADDR', '')
+        self.ipaddress = request.META.get('REMOTE_ADDR', '').split(':')[0]
         if hasattr(request, "user") and request.user.is_authenticated():
             self.user = request.user
 
         # No storing credit card info.
-        query_data = dict((k,v) for k, v in paypal_request.iteritems() if k not in self.RESTRICTED_FIELDS)
+        query_data = dict((k, v) for k, v in paypal_request.iteritems() if k not in self.RESTRICTED_FIELDS)
         self.query = urlencode(query_data)
         self.response = urlencode(paypal_response)
 
@@ -86,6 +88,7 @@ class PayPalNVP(Model):
     def process(self, request, item):
         """Do a direct payment."""
         from paypal.pro.helpers import PayPalWPP
+
         wpp = PayPalWPP(request)
 
         # Change the model information into a dict that PayPal can understand.        
@@ -94,7 +97,7 @@ class PayPalNVP(Model):
         params['creditcardtype'] = self.creditcardtype
         params['expdate'] = self.expdate
         params['cvv2'] = self.cvv2
-        params.update(item)      
+        params.update(item)
 
         # Create recurring payment:
         if 'billingperiod' in params:
