@@ -1,32 +1,14 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 from django.conf import settings
-from django.core.handlers.wsgi import WSGIRequest
 from django.forms import ValidationError
-from django.http import QueryDict
 from django.test import TestCase
-from django.test.client import Client
+from django.test.client import RequestFactory
 
 from paypal.pro.fields import CreditCardField
 from paypal.pro.helpers import PayPalWPP, PayPalError
 from paypal.pro.exceptions import PayPalFailure
 
-class RequestFactory(Client):
-    # Used to generate request objects.
-    def request(self, **request):
-        environ = {
-            'HTTP_COOKIE': self.cookies,
-            'PATH_INFO': '/',
-            'QUERY_STRING': '',
-            'REQUEST_METHOD': 'GET',
-            'SCRIPT_NAME': '',
-            'SERVER_NAME': 'testserver',
-            'SERVER_PORT': 80,
-            'SERVER_PROTOCOL': 'HTTP/1.1',
-        }
-        environ.update(self.defaults)
-        environ.update(request)
-        return WSGIRequest(environ)
 
 RF = RequestFactory()
 REQUEST = RF.get("/pay/", REMOTE_ADDR="127.0.0.1:8000")
@@ -34,6 +16,7 @@ REQUEST = RF.get("/pay/", REMOTE_ADDR="127.0.0.1:8000")
 
 class DummyPayPalWPP(PayPalWPP):
     pass
+
 #     """Dummy class for testing PayPalWPP."""
 #     responses = {
 #         # @@@ Need some reals data here.
@@ -45,20 +28,22 @@ class DummyPayPalWPP(PayPalWPP):
 
 
 class CreditCardFieldTest(TestCase):
-    def testCreditCardField(self):
+    def test_CreditCardField(self):
         field = CreditCardField()
         field.clean('4797503429879309')
         self.assertEquals(field.card_type, "Visa")
         self.assertRaises(ValidationError, CreditCardField().clean, '1234567890123455')
 
-        
+    def test_invalidCreditCards(self):
+        self.assertEquals(CreditCardField().clean('4797-5034-2987-9309'), '4797503429879309')
+
+
 class PayPalWPPTest(TestCase):
     def setUp(self):
-    
         # Avoding blasting real requests at PayPal.
         self.old_debug = settings.DEBUG
         settings.DEBUG = True
-            
+
         self.item = {
             'amt': '9.95',
             'inv': 'inv',
@@ -66,9 +51,9 @@ class PayPalWPPTest(TestCase):
             'next': 'http://www.example.com/next/',
             'returnurl': 'http://www.example.com/pay/',
             'cancelurl': 'http://www.example.com/cancel/'
-        }                    
+        }
         self.wpp = DummyPayPalWPP(REQUEST)
-        
+
     def tearDown(self):
         settings.DEBUG = self.old_debug
 
@@ -89,10 +74,10 @@ class PayPalWPPTest(TestCase):
             'cvv2': '037',
             'acct': '4797503429879309',
             'creditcardtype': 'visa',
-            'ipaddress': '10.0.1.199',}
+            'ipaddress': '10.0.1.199', }
         data.update(self.item)
         self.assertTrue(self.wpp.doDirectPayment(data))
-        
+
     def test_doDirectPayment_invalid(self):
         data = {
             'firstname': 'Epic',
@@ -106,9 +91,9 @@ class PayPalWPPTest(TestCase):
             'cvv2': '999',
             'acct': '1234567890',
             'creditcardtype': 'visa',
-            'ipaddress': '10.0.1.199',}
+            'ipaddress': '10.0.1.199', }
         data.update(self.item)
-        self.assertRaises(PayPalFailure, self.wpp.doDirectPayment(data))
+        self.assertRaises(PayPalFailure, self.wpp.doDirectPayment, data)
 
     def test_setExpressCheckout(self):
         # We'll have to stub out tests for doExpressCheckoutPayment and friends
@@ -147,4 +132,4 @@ class PayPalWPPTest(TestCase):
 #  'token': 'EC-6HW17184NE0084127',
 #  'transactionid': '3TG42202A7335864V',
 #  'transactiontype': 'expresscheckout',
-#  'version': '54.0'}
\ No newline at end of file
+#  'version': '54.0'}
